# Description

[Aviary](https://github.com/Future-House/aviary) is a framework built by [FutureHouse](https://www.futurehouse.org/) for developing tools and environments for LLM agents. This integration allows NeMo Gym rollouts over Aviary environments and datasets.

This agent is intended to be used with the resources servers implemented in `resources_servers/aviary`, which provide the environment and tool interfaces to underlying Aviary implementations.


# Licensing information
Code: Apache 2.0
Data: N/A

Dependencies
- nemo_gym: Apache 2.0
- aviary: Apache 2.0
